Multi Widget
------------

The multi widget allows you to add and edit one or more values.

.. toctree::
   :maxdepth: 1

   Overview <multi>
   Dict integration <multi_dict_integration>
   List integration <multi_list_integration>
